cli

package
v0.0.0-...-2af6a47 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2017 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var App = app{}

App allows command-line callables access to global flags, such as verbosity.

Functions

func Main

func Main() (exitstatus int)

Main is primary entry point into the command line application.

Types

This section is empty.

Directories

Path Synopsis
vol
up

Jump to